## dbt-tests-adapter 1.19.2 - November 04, 2025

### Features

- Add tests for the setting of volatility for sql UDFs ([#1345](https://github.com/dbt-labs/dbt-adapters/issues/1345))
- Create base test for unknown function macro lookup ([#1344](https://github.com/dbt-labs/dbt-adapters/issues/1344))

### Dependencies

- Drop support for python 3.9 ([#1412](https://github.com/dbt-labs/dbt-adapters/pull/1412))
